@@ -5,14 +5,23 @@ from .. import utils
 from . import crud
 
 
-COMMANDS = ["ls", "list", "info", "new", "update", "delete", "rm"]
+COMMANDS = {
+    "ls": "    Retreive accounts list",
+    "list": "  Retreive accounts list",
+    "info": "  Show account information (via --account|-a <ACCOUNT-ID>)",
+    "new": "   Create new account",
+    "update": "Update existing account (via --account|-a <ACCOUNT-ID>)",
+    "delete": "Delete account (via --account|-a <ACCOUNT-ID>)",
+    "rm": "    Delete account (via --account|-a <ACCOUNT-ID>)"
+}
 
 
 def options_validator(ctx, param, args):
     if len(args) == 0 or args[0] not in COMMANDS:
+        cmd = [f"{k}  {v}" for k, v in COMMANDS.items()]
         raise click.UsageError(
-            "Command shoule be one of: `{commands}`".format(
-                commands='`, `'.join(COMMANDS)))
+            "Command shoule be one of:\n\n - {commands}".format(
+                commands='\n - '.join(cmd)))
 
     args = list(args)
     command = args[0]
@@ -41,6 +50,7 @@ def cli():
 @click.argument('options', nargs=-1, type=click.UNPROCESSED,
                 callback=options_validator)
 def accounts(options):
+    """List, create, update, or delete broker accounts"""
     command, options = options
     # print(command, options)
 
