@@ -5,14 +5,21 @@ from .. import utils
 from . import crud
 
 
-COMMANDS = ["ls", "list", "new", "delete", "rm"]
+COMMANDS = {
+    "ls": "    Retreive monitors list",
+    "list": "  Retreive monitors list",
+    "new": "   Create new monitor",
+    "delete": "Delete monitor (via --monitor|-m <MONITOR-ID>)",
+    "rm": "    Delete monitor (via --monitor|-m <MONITOR-ID>)",
+}
 
 
 def options_validator(ctx, param, args):
     if len(args) == 0 or args[0] not in COMMANDS:
+        cmd = [f"{k}  {v}" for k, v in COMMANDS.items()]
         raise click.UsageError(
-            "Command shoule be one of: `{commands}`".format(
-                commands='`, `'.join(COMMANDS)))
+            "Command shoule be one of:\n\n - {commands}".format(
+                commands='\n - '.join(cmd)))
 
     args = list(args)
     command = args[0]
@@ -49,6 +56,7 @@ def cli():
 @click.argument('options', nargs=-1, type=click.UNPROCESSED,
                 callback=options_validator)
 def monitors(options):
+    """List, create, update, or delete monitors"""
     command, options = options
     # print(command, options)
 
